@@ -673,7 +673,7 @@ class DataVars(object):
                                        " " + _("Mode") + " " +_("Value"))
             cl_overriding.printSUCCESS(br)
             for i in plist:
-                if i.endswith("_pw"):
+                if i.endswith("_pw") and varsDict[i].value:
                     p_val = "***"
                 else:
                     p_val=varsDict[i].value
