@@ -400,7 +400,7 @@ class varsShare:
         cmdLine = "/proc/cmdline"
         calculateParam = "calculate"
         names = ("lang","keymap","timezone",
-                    "resolution","video","composite")
+                    "resolution","video","composite","domain","domain_pw")
         # try get timezone from kernel calculate param
         try:
             if type(num) == str and not num.isdigit():
